@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '2.002002'; # VERSION
+our $VERSION = '2.002003'; # VERSION
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -56,9 +56,7 @@ around add_file => sub {
 
 	if ( $self->zilla->copyright_holder ) {
 		for ( split( ' ', $self->zilla->copyright_holder ) ) {
-			my ( $word ) = $_ =~ /(\w{2,})/xms;
-
-			next unless $word;
+			my ( $word ) = $_ =~ /(\w+)/xms;
 
 			$self->log_debug( 'copyright_holder word: ' . $word );
 
@@ -89,7 +87,11 @@ around add_file => sub {
 			{   name    => $file->name,
 				content => $self->fill_in_string(
 					$file->content,
-					{   wordlist      => \$self->wordlist,
+					{
+						name          => __PACKAGE__,
+						version       => __PACKAGE__->VERSION
+							|| 'bootstrapped version',
+						wordlist      => \$self->wordlist,
 						set_spell_cmd => \$set_spell_cmd,
 						add_stopwords => \$add_stopwords,
 						stopwords     => \$stopwords,
@@ -116,7 +118,7 @@ Dist::Zilla::Plugin::Test::PodSpelling - Author tests for POD spelling
 
 =head1 VERSION
 
-version 2.002002
+version 2.002003
 
 =head1 SYNOPSIS
 
@@ -216,14 +218,12 @@ This is free software, licensed under:
 
 __DATA__
 ___[ xt/author/pod-spell.t ]___
-# This test is generated by Dist::Zilla::Plugin::Test::PodSpelling
 use strict;
 use warnings;
 use Test::More;
-use Test::Requires {
-    'Test::Spelling'  => 0.12,
-    '{{ $wordlist }}' => 0,
-};
+
+# generated by {{ $name }} {{ $version }}
+eval "use Test::Spelling 0.12; use {{ $wordlist }}; 1" or die $@;
 
 {{ $set_spell_cmd }}
 {{ $add_stopwords }}
